# Sage version information for Python scripts
# This file is auto-generated by the update-version script, do not edit!
version = '10.8.beta0'
date = '2025-08-16'
banner = 'SageMath version 10.8.beta0, Release Date: 2025-08-16'
